# Utility functions

import os
import sys
import Blender
import re

def isLinux():
	return (not isWindows()) and (not isMac())
	
def isMac():
	return (not isWindows()) and (os.popen("uname").read().strip() == "Darwin")
	
def isWindows():
	return sys.platform[:3] == 'win'

def getAssetsPath():
	return os.path.join(Blender.Get("scriptsdir"), "blendigopkg", "assets")
	
def revealFile(f):
	filename = os.path.basename(f)
	path = os.path.dirname(f)
	
	if isMac():
		os.system("osascript -e 'tell application \"Finder\"\nactivate\nopen folder POSIX file \"" + path + "\"\nselect item \"" + filename + "\" of window 1\nend tell'")
	else:
		# ... something ...
		os.system()
	
def getTempDir():
	if isWindows():
		return os.environ["TMP"]
	elif isMac():
		return "/private/tmp"
	else:
		return "/tmp"

# Return a relative version of a path
#
# From http://bugs.python.org/file6846/relpath.patchd
def getRelativePath(start, path):
	
	if not path:
		raise ValueError("no path specified")

	if not start:
		raise ValueError("no start path specified")

	start_list = os.path.abspath(start).split(os.path.sep)
	path_list = path.split(os.path.sep)

	if isWindows():
		if start_list[0].lower() != path_list[0].lower():
			return path
		
  # Work out how much of the filepath is shared by start and path.
	for i in range(min(len(start_list), len(path_list))):
		if start_list[i].lower() != path_list[i].lower():
			break
		else:
			i += 1

	rel_list = [os.path.pardir] * (len(start_list)-i-1) + path_list[i:]
	return os.path.join(*rel_list)


# Remove all the characters from a string that have special meanings in filenames, and replace with '_'.
def makeSafeFilename(s):
	regexp = re.compile(r'\W') # \W = [^a-zA-Z0-9_]
	return regexp.sub("_", s)
